// And.java - AND interface
// Rob Earhart
// $Id$
//
/***********************************************************
        Copyright 1997 by Carnegie Mellon University

                      All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of CMU not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.
******************************************************************/

package acap;

import java.io.DataOutputStream;

/**
 * And is a composite criteria object, selecting entries which
 * match both of two other criteria
 * @see acap.Conn
 */
public class And extends Criteria {
  private Criteria a, b;
   /**
   * Constructs an And object representing the
   * intersection of the specified criteria.
   * @param first the first criteria that must be matched
   * @param second the second criteria that must be matched
   */
 public And(Criteria first, Criteria second) {
    this.a = first;
    this.b = second;
  }
  void Send(DataOutputStream out)
    throws java.io.IOException {
      out.writeByte('(');
      a.Send(out);
      out.writeByte(' ');
      b.Send(out);
      out.writeByte(')');
  }
}
